% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vda.r
\name{vda}
\alias{vda}
\title{Vargha and Delaney's A}
\usage{
vda(
  formula = NULL,
  data = NULL,
  x = NULL,
  y = NULL,
  ci = FALSE,
  conf = 0.95,
  type = "perc",
  R = 1000,
  histogram = FALSE,
  reportIncomplete = FALSE,
  brute = FALSE,
  verbose = FALSE,
  digits = 3,
  ...
)
}
\arguments{
\item{formula}{A formula indicating the response variable and
the independent variable. e.g. y ~ group.}

\item{data}{The data frame to use.}

\item{x}{If no formula is given, the response variable for one group.}

\item{y}{The response variable for the other group.}

\item{ci}{If \code{TRUE}, returns confidence intervals by bootstrap.
May be slow.}

\item{conf}{The level for the confidence interval.}

\item{type}{The type of confidence interval to use.
Can be any of "\code{norm}", "\code{basic}", 
              "\code{perc}", or "\code{bca}".
Passed to \code{boot.ci}.}

\item{R}{The number of replications to use for bootstrap.}

\item{histogram}{If \code{TRUE}, produces a histogram of bootstrapped values.}

\item{reportIncomplete}{If \code{FALSE} (the default),
\code{NA} will be reported in cases where there
are instances of the calculation of the statistic
failing during the bootstrap procedure.}

\item{brute}{If \code{FALSE}, the default, the statistic is based on the
U statistic from the \code{wilcox.test} function.
If \code{TRUE}, the function will compare values
in the two samples directly.}

\item{verbose}{If \code{TRUE}, reports the proportion of ties and
the proportions of (Ya > Yb) and (Ya < Yb).}

\item{digits}{The number of significant digits in the output.}

\item{...}{Additional arguments passed to the \code{wilcox.test} function.}
}
\value{
A single statistic, VDA.
        Or a small data frame consisting of VDA,
        and the lower and upper confidence limits.
}
\description{
Calculates Vargha and Delaney's A (VDA)
             with confidence intervals by bootstrap
}
\details{
VDA is an effect size statistic appropriate
         in cases where a Wilcoxon-Mann-Whitney test might be used.
         It ranges from 0 to 1, with 0.5 indicating stochastic equality,
         and 1 indicating that the first group dominates the second.
         
         By default, the function calculates VDA from the "W" U statistic
         from the \code{wilcox.test} function.
         Specifically, \code{VDA = U/(n1*n2)}.
           
         The input should include either \code{formula} and \code{data};
         or \code{x}, and \code{y}. If there are more than two groups,
         only the first two groups are used.
         
         Currently, the function makes no provisions for \code{NA}
         values in the data.  It is recommended that \code{NA}s be removed
         beforehand.
          
         When the data in the first group are greater than
         in the second group, VDA is greater than 0.5.
         When the data in the second group are greater than
         in the first group, VDA is less than 0.5.
         
         Be cautious with this interpretation, as R will alphabetize
         groups in the formula interface if the grouping variable
         is not already a factor.

         When VDA is close to 0 or close to 1,
         or with small sample size,
         the confidence intervals 
         determined by this
         method may not be reliable, or the procedure may fail.
}
\note{
The parsing of the formula is simplistic. 
         The first variable on the
         left side is used as the measurement variable.  
         The first variable on the
         right side is used for the grouping variable.
}
\examples{
data(Catbus)
vda(Steps ~ Sex, data=Catbus)

}
\references{
\url{http://rcompanion.org/handbook/F_04.html}
}
\seealso{
\code{\link{cliffDelta}}, \code{\link{multiVDA}}
}
\author{
Salvatore Mangiafico, \email{mangiafico@njaes.rutgers.edu}
}
\concept{effect size}
